#
# spec file for package hpx
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019 Christoph Junghans
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hpx
Version:        1.10.0
Release:        1.3
Summary:        General Purpose C++ Runtime System
License:        BSL-1.0
Group:          Productivity/Networking/Other
URL:            https://stellar.cct.lsu.edu/tag/hpx/
Source0:        https://github.com/STEllAR-GROUP/hpx/archive/refs/tags/v%{version}.tar.gz#/%{name}_%{version}.tar.gz
Patch1:         remove-dependency-to-obsolete-boot-filesystem-path-basename.patch
Patch2:         scope-fix-issue-with-GCC-9.patch
Patch3:         remove-maybe_unused.patch
BuildRequires:  asio-devel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gperftools-devel
BuildRequires:  hwloc-devel
BuildRequires:  libboost_atomic-devel >= 1.71
BuildRequires:  libboost_filesystem-devel >= 1.71
BuildRequires:  libboost_iostreams-devel >= 1.71
BuildRequires:  libboost_program_options-devel >= 1.71
BuildRequires:  libboost_regex-devel >= 1.71
BuildRequires:  libboost_system-devel >= 1.71
%ifarch aarch64 %{arm}
BuildRequires:  libboost_chrono-devel >= 1.71
BuildRequires:  libboost_context-devel >= 1.71
BuildRequires:  libboost_thread-devel >= 1.71
%endif
BuildRequires:  openmpi-macros-devel
Requires:       libhpx1 = %{version}-%{release}
ExcludeArch:    i586 %arm

%description
HPX is a general purpose C++ runtime system for parallel and distributed applications of any scale.

%package devel
Summary:        Development headers and libraries for hpx
Group:          Development/Libraries/C and C++
Requires:       libhpx1 = %{version}-%{release}
%{openmpi_devel_requires}

%description devel
HPX is a general purpose C++ runtime system for parallel and distributed applications of any scale.

This package contains development headers and libraries for hpx

%package -n libhpx1
Summary:        Libraries for the hpx package
Group:          System/Libraries
%{openmpi_requires}

%description -n libhpx1
HPX is a general purpose C++ runtime system for parallel and distributed applications of any scale.

This package contains libraries for the hpx package.

%prep
%define _lto_cflags %{nil}
%autosetup -p0

%build
%ifarch aarch64 %{arm}
%define cmake_opts -DHPX_WITH_GENERIC_CONTEXT_COROUTINES=ON
%endif

# add lib atomic for s390x and ppc64
%ifarch s390x ppc64
%define cmake_opts -DCMAKE_SHARED_LINKER_FLAGS="%{optflags} -Wl,--push-state,--no-as-needed -latomic -Wl,--pop-state" -DCMAKE_EXE_LINKER_FLAGS="%{optflags} -Wl,--push-state,--no-as-needed -latomic -Wl,--pop-state"
%endif

%{setup_openmpi}
%cmake -DLIB=%{_lib} %{?cmake_opts:%cmake_opts} \
 -DHPX_WITH_BUILD_BINARY_PACKAGE=ON \
 -DHPX_WITH_EXAMPLES=OFF
make -j1

%install
make -C build install DESTDIR=%{buildroot}
rm %{buildroot}/%{_datadir}/%{name}/LICENSE_1_0.txt
# Remove static libs and extra binaries
rm -f %{buildroot}/%{_libdir}/*.a
rm -f %{buildroot}/%{_bindir}/hpx_run_test.py
%fdupes %{buildroot}%{_prefix}

sed -i '1s@env @@' %{buildroot}/%{_bindir}/{hpx*.py,hpxcxx}

%post -n libhpx1 -p /sbin/ldconfig
%postun -n libhpx1 -p /sbin/ldconfig

%files
%{_bindir}/hpx*.py
%doc README.rst
%license LICENSE_1_0.txt

%files -n libhpx1
%license LICENSE_1_0.txt
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/lib*.so.*
%{_libdir}/lib*.so.*

%files devel
%{_bindir}/hpxcxx
%{_includedir}/%{name}
%{_libdir}/lib*.so
%{_libdir}/%{name}/lib*.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/HPX

%changelog
* Tue Jun 25 2024 Nicolas Morey <nicolas.morey@suse.com>
- Udpate to 1.10.0
  - See https://hpx-docs.stellar-group.org/tags/v1.10.0/html/releases/whats_new_1_10_0.html
  for what's new.
- Drop Add-missing-header-for-std-intmax_t.patch as it was fixed upstream.
- Disable i586 build as asio-devel is not available.
- Disable broken arm 32b build
- Add explicit dependency to boost >= 1.71
- Add patches to fix compilation on Leap 15.5 and 15.6
  - remove-dependency-to-obsolete-boot-filesystem-path-basename.patch
  - scope-fix-issue-with-GCC-9.patch
  - remove-maybe_unused.patch
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Wed Mar 29 2023 Nicolas Morey <nicolas.morey@suse.com>
- Add Add-missing-header-for-std-intmax_t.patch for GCC13 support
* Thu Sep 15 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to 1.8.1
  - Major overall changes. See https://hpx-docs.stellar-group.org/ for more details
* Wed Apr 28 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to 1.6.0
  - Continued focus on C++20 conformance with multiple
    new algorithms adapted to be C++20 conformant
  - hpxMP support has been completely removed.
  - The ``verbs`` parcelport has been removed.
* Tue Sep  8 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to 1.5.0
  - Continued modularization. Deprecation of several headers moved to a different location
  - Several algorithms adapted to be C++20 conformant and added hpx::stable_sort.
  - Refactored the CMake target, it is now possible to link directly to HPX::hpx
  - Now requires a C++14 compatible compiler and the standard is set by default to C++14.
* Wed Jun 10 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to 1.4.1
  - Fixes compilation issues with GCC10
- Disable parallel build to avoid OoM errors in OBS
* Wed Feb  5 2020 Ismail Dönmez <idonmez@suse.com>
- Cleanup spec file
* Tue Jan 28 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to 1.4.0
- Disable tests build and run as they take huge amount of CPU time
- Drop static libraries
* Tue Jan 28 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Disable LTO as it messes up with some linker flags used by HPX
* Mon May 27 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Always use the default openmpi
* Wed Mar 20 2019 Christoph Junghans <junghans@votca.org>
- Version bump to 1.2.1
  * Compilation on various platforms
  * A critical bug in the future implementation
  * Various CMake bugs
- Drop 3551.patch, 3557.patch, reproducible.patch and 3591.patch - merged upstream
* Tue Mar 19 2019 Christoph Junghans <junghans@votca.org>
- Fix build with boost-1.69
* Mon Dec 31 2018 Manu Maier <mmanu84@outlook.de>
- fix build on armv6
* Wed Dec 19 2018 Bernhard Wiedemann <bwiedemann@suse.com>
- Update reproducible.patch to match what was merged upstream
* Sun Dec 16 2018 Christoph Junghans <junghans@votca.org>
- Added 3591.patch to fix build on %%arm
* Fri Dec  7 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update _constraints with latest requirements
* Tue Dec  4 2018 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to not consider the build machine CPU
  capabilities for the build result (boo#1100677)
* Sun Nov 25 2018 Christoph Junghans <junghans@votca.org>
- Put static libraries into hpx-static package
* Mon Nov 19 2018 Christoph Junghans <junghans@votca.org>
- Added 3557.patch to fix build on ppc64
* Sun Nov 18 2018 Christoph Junghans <junghans@votca.org>
- Re-enable build on ppc64le
* Wed Nov 14 2018 Christoph Junghans <junghans@votca.org>
- Version bump to 1.2.0
  Full log here: https://stellar-group.github.io/hpx/docs/sphinx/tags/1.2.0/html/releases/whats_new_1_2_0.html
- added upstream 3551.patch to fix build on i586
* Mon Nov 12 2018 Jan Engelhardt <jengelh@inai.de>
- Remove future goals from description.
* Tue Oct 30 2018 Christoph Junghans <junghans@votca.org>
- Version bump to 1.1.0
- Dropped hpx_0.9.8-pr1137.patch, merged upstream
* Tue May 27 2014 junghans@votca.org
- initial commit
